@@ -1444,12 +1444,6 @@ class ContainerCLI(DockerCLICaller):
 
         full_cmd.add_flag("--init", init)
 
-        # TODO: activate interactive and tty
-        if interactive and not tty:
-            raise NotImplementedError(
-                "Currently, docker.container.run(interactive=True) must have"
-                "tty=True. interactive=True and tty=False is not yet implemented."
-            )
         full_cmd.add_flag("--interactive", interactive)
         full_cmd.add_flag("--tty", tty)
 
@@ -1535,17 +1529,6 @@ class ContainerCLI(DockerCLICaller):
                     "It's not possible to stream and detach a container at "
                     "the same time."
                 )
-            if interactive:
-                raise ValueError(
-                    "It's not possible to interact and detach a container at "
-                    "the same time."
-                )
-        if stream and interactive:
-            if interactive:
-                raise ValueError(
-                    "It's not possible to interact and stream a container at "
-                    "the same time."
-                )
         if detach:
             return Container(self.client_config, run(full_cmd))
         elif stream:
